====================
RuleExhaustiveBallot
====================

.. autoclass:: svvamp.RuleExhaustiveBallot
   :members: ballots_, scores_, candidates_by_scores_best_to_worst_, w_, margins_, elimination_path_
